# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SYNTHMORPH_METADATA = Metadata(
    id="4ad8493a581d5747e29206723591f18bb45ae13f.boutiques",
    name="mri_synthmorph",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSynthmorphOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_synthmorph(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    moved_output_file: OutputPathType | None
    """The registered output image file, resulting from the operation."""
    transform_output_file: OutputPathType
    """Transform file resulting from registration."""


def mri_synthmorph(
    moved_output: InputPathType | None = None,
    init_transform: InputPathType | None = None,
    threads: float | None = None,
    gpu_flag: bool = False,
    smooth: float | None = 1,
    extent: float | None = 256,
    model_weights: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriSynthmorphOutputs:
    """
    SynthMorph is a deep-learning tool for brain-specific MRI image registration
    without preprocessing.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        moved_output: The resulting image after registration.
        init_transform: Initial linear transform for registration.
        threads: Number of TensorFlow threads to utilize. Defaults to the\
            number of cores.
        gpu_flag: Utilize the GPU specified by CUDA_VISIBLE_DEVICES or GPU 0 if\
            unset or empty.
        smooth: Regularization parameter for deformable registration. Higher\
            values indicate smoother displacement fields.
        extent: Isotropic extent of the registration space in unit voxels.
        model_weights: Alternative model weights as an H5 file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSynthmorphOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SYNTHMORPH_METADATA)
    cargs = []
    cargs.append("mri_synthmorph")
    cargs.append("[MOVING]")
    cargs.append("[FIXED]")
    if moved_output is not None:
        cargs.extend([
            "-o",
            execution.input_file(moved_output)
        ])
    cargs.append("[TRANS_OUTPUT]")
    cargs.append("[HEADER_ONLY_FLAG]")
    cargs.append("[MODEL]")
    if init_transform is not None:
        cargs.extend([
            "-i",
            execution.input_file(init_transform)
        ])
    if threads is not None:
        cargs.extend([
            "-j",
            str(threads)
        ])
    if gpu_flag:
        cargs.append("-g")
    if smooth is not None:
        cargs.extend([
            "-s",
            str(smooth)
        ])
    if extent is not None:
        cargs.extend([
            "-e",
            str(extent)
        ])
    if model_weights is not None:
        cargs.extend([
            "-w",
            execution.input_file(model_weights)
        ])
    cargs.append("[INSPECT_DIR]")
    ret = MriSynthmorphOutputs(
        root=execution.output_file("."),
        moved_output_file=execution.output_file(pathlib.Path(moved_output).name) if (moved_output is not None) else None,
        transform_output_file=execution.output_file("[TRANS_OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SYNTHMORPH_METADATA",
    "MriSynthmorphOutputs",
    "mri_synthmorph",
]
